% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/DataFrame.R, R/functions.R, R/generics.R
\docType{methods}
\name{coalesce}
\alias{coalesce}
\alias{coalesce,Column-method}
\alias{coalesce,SparkDataFrame-method}
\title{Coalesce}
\usage{
\S4method{coalesce}{SparkDataFrame}(x, numPartitions)

\S4method{coalesce}{Column}(x, ...)

coalesce(x, ...)
}
\arguments{
\item{x}{a Column or a SparkDataFrame.}

\item{numPartitions}{the number of partitions to use.}

\item{...}{additional argument(s). If \code{x} is a Column, additional Columns can be optionally
provided.}
}
\description{
Returns a new SparkDataFrame that has exactly \code{numPartitions} partitions.
This operation results in a narrow dependency, e.g. if you go from 1000 partitions to 100
partitions, there will not be a shuffle, instead each of the 100 new partitions will claim 10 of
the current partitions. If a larger number of partitions is requested, it will stay at the
current number of partitions.

Returns the first column that is not NA, or NA if all inputs are.
}
\details{
However, if you're doing a drastic coalesce on a SparkDataFrame, e.g. to numPartitions = 1,
this may result in your computation taking place on fewer nodes than
you like (e.g. one node in the case of numPartitions = 1). To avoid this,
call \code{repartition}. This will add a shuffle step, but means the
current upstream partitions will be executed in parallel (per whatever
the current partitioning is).
}
\note{
coalesce(SparkDataFrame) since 2.1.1

coalesce(Column) since 2.1.1
}
\examples{
\dontrun{
sparkR.session()
path <- "path/to/file.json"
df <- read.json(path)
newDF <- coalesce(df, 1L)
}
\dontrun{coalesce(df$c, df$d, df$e)}
}
\seealso{
\link{repartition}

Other SparkDataFrame functions: \code{\link{$}},
  \code{\link{$,SparkDataFrame-method}}, \code{\link{$<-}},
  \code{\link{$<-,SparkDataFrame-method}},
  \code{\link{select}}, \code{\link{select}},
  \code{\link{select,SparkDataFrame,Column-method}},
  \code{\link{select,SparkDataFrame,character-method}},
  \code{\link{select,SparkDataFrame,list-method}};
  \code{\link{SparkDataFrame-class}}; \code{\link{[}},
  \code{\link{[,SparkDataFrame-method}}, \code{\link{[[}},
  \code{\link{[[,SparkDataFrame,numericOrcharacter-method}},
  \code{\link{[[<-}},
  \code{\link{[[<-,SparkDataFrame,numericOrcharacter-method}},
  \code{\link{subset}}, \code{\link{subset}},
  \code{\link{subset,SparkDataFrame-method}};
  \code{\link{agg}}, \code{\link{agg}}, \code{\link{agg}},
  \code{\link{agg,GroupedData-method}},
  \code{\link{agg,SparkDataFrame-method}},
  \code{\link{summarize}}, \code{\link{summarize}},
  \code{\link{summarize}},
  \code{\link{summarize,GroupedData-method}},
  \code{\link{summarize,SparkDataFrame-method}};
  \code{\link{arrange}}, \code{\link{arrange}},
  \code{\link{arrange}},
  \code{\link{arrange,SparkDataFrame,Column-method}},
  \code{\link{arrange,SparkDataFrame,character-method}},
  \code{\link{orderBy,SparkDataFrame,characterOrColumn-method}};
  \code{\link{as.data.frame}},
  \code{\link{as.data.frame,SparkDataFrame-method}};
  \code{\link{attach}},
  \code{\link{attach,SparkDataFrame-method}};
  \code{\link{cache}}, \code{\link{cache}},
  \code{\link{cache,SparkDataFrame-method}};
  \code{\link{collect}}, \code{\link{collect}},
  \code{\link{collect,SparkDataFrame-method}};
  \code{\link{colnames}}, \code{\link{colnames}},
  \code{\link{colnames,SparkDataFrame-method}},
  \code{\link{colnames<-}}, \code{\link{colnames<-}},
  \code{\link{colnames<-,SparkDataFrame-method}},
  \code{\link{columns}}, \code{\link{columns}},
  \code{\link{columns,SparkDataFrame-method}},
  \code{\link{names}},
  \code{\link{names,SparkDataFrame-method}},
  \code{\link{names<-}},
  \code{\link{names<-,SparkDataFrame-method}};
  \code{\link{coltypes}}, \code{\link{coltypes}},
  \code{\link{coltypes,SparkDataFrame-method}},
  \code{\link{coltypes<-}}, \code{\link{coltypes<-}},
  \code{\link{coltypes<-,SparkDataFrame,character-method}};
  \code{\link{count,SparkDataFrame-method}},
  \code{\link{nrow}}, \code{\link{nrow}},
  \code{\link{nrow,SparkDataFrame-method}};
  \code{\link{createOrReplaceTempView}},
  \code{\link{createOrReplaceTempView}},
  \code{\link{createOrReplaceTempView,SparkDataFrame,character-method}};
  \code{\link{crossJoin}},
  \code{\link{crossJoin,SparkDataFrame,SparkDataFrame-method}};
  \code{\link{dapplyCollect}}, \code{\link{dapplyCollect}},
  \code{\link{dapplyCollect,SparkDataFrame,function-method}};
  \code{\link{dapply}}, \code{\link{dapply}},
  \code{\link{dapply,SparkDataFrame,function,structType-method}};
  \code{\link{describe}}, \code{\link{describe}},
  \code{\link{describe}},
  \code{\link{describe,SparkDataFrame,ANY-method}},
  \code{\link{describe,SparkDataFrame,character-method}},
  \code{\link{describe,SparkDataFrame-method}},
  \code{\link{summary}}, \code{\link{summary}},
  \code{\link{summary,SparkDataFrame-method}};
  \code{\link{dim}},
  \code{\link{dim,SparkDataFrame-method}};
  \code{\link{distinct}}, \code{\link{distinct}},
  \code{\link{distinct,SparkDataFrame-method}},
  \code{\link{unique}},
  \code{\link{unique,SparkDataFrame-method}};
  \code{\link{dropDuplicates}},
  \code{\link{dropDuplicates}},
  \code{\link{dropDuplicates,SparkDataFrame-method}};
  \code{\link{dropna}}, \code{\link{dropna}},
  \code{\link{dropna,SparkDataFrame-method}},
  \code{\link{fillna}}, \code{\link{fillna}},
  \code{\link{fillna,SparkDataFrame-method}},
  \code{\link{na.omit}}, \code{\link{na.omit}},
  \code{\link{na.omit,SparkDataFrame-method}};
  \code{\link{drop}}, \code{\link{drop}},
  \code{\link{drop}}, \code{\link{drop,ANY-method}},
  \code{\link{drop,SparkDataFrame-method}};
  \code{\link{dtypes}}, \code{\link{dtypes}},
  \code{\link{dtypes,SparkDataFrame-method}};
  \code{\link{except}}, \code{\link{except}},
  \code{\link{except,SparkDataFrame,SparkDataFrame-method}};
  \code{\link{explain}}, \code{\link{explain}},
  \code{\link{explain,SparkDataFrame-method}};
  \code{\link{filter}}, \code{\link{filter}},
  \code{\link{filter,SparkDataFrame,characterOrColumn-method}},
  \code{\link{where}}, \code{\link{where}},
  \code{\link{where,SparkDataFrame,characterOrColumn-method}};
  \code{\link{first}}, \code{\link{first}},
  \code{\link{first}},
  \code{\link{first,SparkDataFrame-method}},
  \code{\link{first,characterOrColumn-method}};
  \code{\link{gapplyCollect}}, \code{\link{gapplyCollect}},
  \code{\link{gapplyCollect}},
  \code{\link{gapplyCollect,GroupedData-method}},
  \code{\link{gapplyCollect,SparkDataFrame-method}};
  \code{\link{gapply}}, \code{\link{gapply}},
  \code{\link{gapply}},
  \code{\link{gapply,GroupedData-method}},
  \code{\link{gapply,SparkDataFrame-method}};
  \code{\link{getNumPartitions}},
  \code{\link{getNumPartitions,SparkDataFrame-method}};
  \code{\link{groupBy}}, \code{\link{groupBy}},
  \code{\link{groupBy,SparkDataFrame-method}},
  \code{\link{group_by}}, \code{\link{group_by}},
  \code{\link{group_by,SparkDataFrame-method}};
  \code{\link{head}},
  \code{\link{head,SparkDataFrame-method}};
  \code{\link{histogram}},
  \code{\link{histogram,SparkDataFrame,characterOrColumn-method}};
  \code{\link{insertInto}}, \code{\link{insertInto}},
  \code{\link{insertInto,SparkDataFrame,character-method}};
  \code{\link{intersect}}, \code{\link{intersect}},
  \code{\link{intersect,SparkDataFrame,SparkDataFrame-method}};
  \code{\link{isLocal}}, \code{\link{isLocal}},
  \code{\link{isLocal,SparkDataFrame-method}};
  \code{\link{join}},
  \code{\link{join,SparkDataFrame,SparkDataFrame-method}};
  \code{\link{limit}}, \code{\link{limit}},
  \code{\link{limit,SparkDataFrame,numeric-method}};
  \code{\link{merge}}, \code{\link{merge}},
  \code{\link{merge,SparkDataFrame,SparkDataFrame-method}};
  \code{\link{mutate}}, \code{\link{mutate}},
  \code{\link{mutate,SparkDataFrame-method}},
  \code{\link{transform}}, \code{\link{transform}},
  \code{\link{transform,SparkDataFrame-method}};
  \code{\link{ncol}},
  \code{\link{ncol,SparkDataFrame-method}};
  \code{\link{persist}}, \code{\link{persist}},
  \code{\link{persist,SparkDataFrame,character-method}};
  \code{\link{printSchema}}, \code{\link{printSchema}},
  \code{\link{printSchema,SparkDataFrame-method}};
  \code{\link{randomSplit}}, \code{\link{randomSplit}},
  \code{\link{randomSplit,SparkDataFrame,numeric-method}};
  \code{\link{rbind}}, \code{\link{rbind}},
  \code{\link{rbind,SparkDataFrame-method}};
  \code{\link{registerTempTable}},
  \code{\link{registerTempTable}},
  \code{\link{registerTempTable,SparkDataFrame,character-method}};
  \code{\link{rename}}, \code{\link{rename}},
  \code{\link{rename,SparkDataFrame-method}},
  \code{\link{withColumnRenamed}},
  \code{\link{withColumnRenamed}},
  \code{\link{withColumnRenamed,SparkDataFrame,character,character-method}};
  \code{\link{repartition}}, \code{\link{repartition}},
  \code{\link{repartition,SparkDataFrame-method}};
  \code{\link{sample}}, \code{\link{sample}},
  \code{\link{sample,SparkDataFrame,logical,numeric-method}},
  \code{\link{sample_frac}}, \code{\link{sample_frac}},
  \code{\link{sample_frac,SparkDataFrame,logical,numeric-method}};
  \code{\link{saveAsParquetFile}},
  \code{\link{saveAsParquetFile}},
  \code{\link{saveAsParquetFile,SparkDataFrame,character-method}},
  \code{\link{write.parquet}}, \code{\link{write.parquet}},
  \code{\link{write.parquet,SparkDataFrame,character-method}};
  \code{\link{saveAsTable}}, \code{\link{saveAsTable}},
  \code{\link{saveAsTable,SparkDataFrame,character-method}};
  \code{\link{saveDF}}, \code{\link{saveDF}},
  \code{\link{saveDF,SparkDataFrame,character-method}},
  \code{\link{write.df}}, \code{\link{write.df}},
  \code{\link{write.df}},
  \code{\link{write.df,SparkDataFrame-method}};
  \code{\link{schema}}, \code{\link{schema}},
  \code{\link{schema,SparkDataFrame-method}};
  \code{\link{selectExpr}}, \code{\link{selectExpr}},
  \code{\link{selectExpr,SparkDataFrame,character-method}};
  \code{\link{showDF}}, \code{\link{showDF}},
  \code{\link{showDF,SparkDataFrame-method}};
  \code{\link{show}}, \code{\link{show}},
  \code{\link{show,Column-method}},
  \code{\link{show,GroupedData-method}},
  \code{\link{show,SparkDataFrame-method}},
  \code{\link{show,WindowSpec-method}};
  \code{\link{storageLevel}},
  \code{\link{storageLevel,SparkDataFrame-method}};
  \code{\link{str}},
  \code{\link{str,SparkDataFrame-method}};
  \code{\link{take}}, \code{\link{take}},
  \code{\link{take,SparkDataFrame,numeric-method}};
  \code{\link{union}}, \code{\link{union}},
  \code{\link{union,SparkDataFrame,SparkDataFrame-method}},
  \code{\link{unionAll}}, \code{\link{unionAll}},
  \code{\link{unionAll,SparkDataFrame,SparkDataFrame-method}};
  \code{\link{unpersist}}, \code{\link{unpersist}},
  \code{\link{unpersist,SparkDataFrame-method}};
  \code{\link{withColumn}}, \code{\link{withColumn}},
  \code{\link{withColumn,SparkDataFrame,character-method}};
  \code{\link{with}},
  \code{\link{with,SparkDataFrame-method}};
  \code{\link{write.jdbc}}, \code{\link{write.jdbc}},
  \code{\link{write.jdbc,SparkDataFrame,character,character-method}};
  \code{\link{write.json}}, \code{\link{write.json}},
  \code{\link{write.json,SparkDataFrame,character-method}};
  \code{\link{write.orc}}, \code{\link{write.orc}},
  \code{\link{write.orc,SparkDataFrame,character-method}};
  \code{\link{write.text}}, \code{\link{write.text}},
  \code{\link{write.text,SparkDataFrame,character-method}}

Other normal_funcs: \code{\link{Column-class}},
  \code{\link{column}}, \code{\link{column}},
  \code{\link{column}},
  \code{\link{column,character-method}},
  \code{\link{column,jobj-method}}; \code{\link{abs}},
  \code{\link{abs,Column-method}};
  \code{\link{bitwiseNOT}}, \code{\link{bitwiseNOT}},
  \code{\link{bitwiseNOT,Column-method}};
  \code{\link{expr}}, \code{\link{expr}},
  \code{\link{expr,character-method}};
  \code{\link{greatest}}, \code{\link{greatest}},
  \code{\link{greatest,Column-method}};
  \code{\link{ifelse}}, \code{\link{ifelse,Column-method}};
  \code{\link{is.nan}}, \code{\link{is.nan,Column-method}},
  \code{\link{isnan}}, \code{\link{isnan}},
  \code{\link{isnan,Column-method}}; \code{\link{least}},
  \code{\link{least}}, \code{\link{least,Column-method}};
  \code{\link{lit}}, \code{\link{lit}},
  \code{\link{lit,ANY-method}}; \code{\link{nanvl}},
  \code{\link{nanvl}}, \code{\link{nanvl,Column-method}};
  \code{\link{negate}}, \code{\link{negate}},
  \code{\link{negate,Column-method}}; \code{\link{randn}},
  \code{\link{randn}}, \code{\link{randn}},
  \code{\link{randn,missing-method}},
  \code{\link{randn,numeric-method}}; \code{\link{rand}},
  \code{\link{rand}}, \code{\link{rand}},
  \code{\link{rand,missing-method}},
  \code{\link{rand,numeric-method}}; \code{\link{struct}},
  \code{\link{struct}},
  \code{\link{struct,characterOrColumn-method}};
  \code{\link{when}}, \code{\link{when}},
  \code{\link{when,Column-method}}
}

