% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/functions.R, R/generics.R, R/stats.R
\docType{methods}
\name{corr}
\alias{corr}
\alias{corr,Column-method}
\alias{corr,SparkDataFrame-method}
\title{corr}
\usage{
\S4method{corr}{Column}(x, col2)

corr(x, ...)

\S4method{corr}{SparkDataFrame}(x, colName1, colName2, method = "pearson")
}
\arguments{
\item{x}{a Column or a SparkDataFrame.}

\item{col2}{a (second) Column.}

\item{...}{additional argument(s). If \code{x} is a Column, a Column
should be provided. If \code{x} is a SparkDataFrame, two column names should
be provided.}

\item{colName1}{the name of the first column}

\item{colName2}{the name of the second column}

\item{method}{Optional. A character specifying the method for calculating the correlation.
only "pearson" is allowed now.}
}
\value{
The Pearson Correlation Coefficient as a Double.
}
\description{
Computes the Pearson Correlation Coefficient for two Columns.

Calculates the correlation of two columns of a SparkDataFrame.
Currently only supports the Pearson Correlation Coefficient.
For Spearman Correlation, consider using RDD methods found in MLlib's Statistics.
}
\note{
corr since 1.6.0

corr since 1.6.0
}
\examples{
\dontrun{corr(df$c, df$d)}
\dontrun{
df <- read.json("/path/to/file.json")
corr <- corr(df, "title", "gender")
corr <- corr(df, "title", "gender", method = "pearson")
}
}
\seealso{
Other math_funcs: \code{\link{acos}},
  \code{\link{acos,Column-method}}; \code{\link{asin}},
  \code{\link{asin,Column-method}}; \code{\link{atan2}},
  \code{\link{atan2,Column-method}}; \code{\link{atan}},
  \code{\link{atan,Column-method}}; \code{\link{bin}},
  \code{\link{bin}}, \code{\link{bin,Column-method}};
  \code{\link{bround}}, \code{\link{bround}},
  \code{\link{bround,Column-method}}; \code{\link{cbrt}},
  \code{\link{cbrt}}, \code{\link{cbrt,Column-method}};
  \code{\link{ceil}}, \code{\link{ceil}},
  \code{\link{ceil,Column-method}}, \code{\link{ceiling}},
  \code{\link{ceiling,Column-method}}; \code{\link{conv}},
  \code{\link{conv}},
  \code{\link{conv,Column,numeric,numeric-method}};
  \code{\link{cosh}}, \code{\link{cosh,Column-method}};
  \code{\link{cos}}, \code{\link{cos,Column-method}};
  \code{\link{covar_pop}}, \code{\link{covar_pop}},
  \code{\link{covar_pop,characterOrColumn,characterOrColumn-method}};
  \code{\link{cov}}, \code{\link{cov}}, \code{\link{cov}},
  \code{\link{cov,SparkDataFrame-method}},
  \code{\link{cov,characterOrColumn-method}},
  \code{\link{covar_samp}}, \code{\link{covar_samp}},
  \code{\link{covar_samp,characterOrColumn,characterOrColumn-method}};
  \code{\link{expm1}}, \code{\link{expm1,Column-method}};
  \code{\link{exp}}, \code{\link{exp,Column-method}};
  \code{\link{factorial}},
  \code{\link{factorial,Column-method}};
  \code{\link{floor}}, \code{\link{floor,Column-method}};
  \code{\link{hex}}, \code{\link{hex}},
  \code{\link{hex,Column-method}}; \code{\link{hypot}},
  \code{\link{hypot}}, \code{\link{hypot,Column-method}};
  \code{\link{log10}}, \code{\link{log10,Column-method}};
  \code{\link{log1p}}, \code{\link{log1p,Column-method}};
  \code{\link{log2}}, \code{\link{log2,Column-method}};
  \code{\link{log}}, \code{\link{log,Column-method}};
  \code{\link{pmod}}, \code{\link{pmod}},
  \code{\link{pmod,Column-method}}; \code{\link{rint}},
  \code{\link{rint}}, \code{\link{rint,Column-method}};
  \code{\link{round}}, \code{\link{round,Column-method}};
  \code{\link{shiftLeft}}, \code{\link{shiftLeft}},
  \code{\link{shiftLeft,Column,numeric-method}};
  \code{\link{shiftRightUnsigned}},
  \code{\link{shiftRightUnsigned}},
  \code{\link{shiftRightUnsigned,Column,numeric-method}};
  \code{\link{shiftRight}}, \code{\link{shiftRight}},
  \code{\link{shiftRight,Column,numeric-method}};
  \code{\link{sign}}, \code{\link{sign,Column-method}},
  \code{\link{signum}}, \code{\link{signum}},
  \code{\link{signum,Column-method}}; \code{\link{sinh}},
  \code{\link{sinh,Column-method}}; \code{\link{sin}},
  \code{\link{sin,Column-method}}; \code{\link{sqrt}},
  \code{\link{sqrt,Column-method}}; \code{\link{tanh}},
  \code{\link{tanh,Column-method}}; \code{\link{tan}},
  \code{\link{tan,Column-method}}; \code{\link{toDegrees}},
  \code{\link{toDegrees}},
  \code{\link{toDegrees,Column-method}};
  \code{\link{toRadians}}, \code{\link{toRadians}},
  \code{\link{toRadians,Column-method}};
  \code{\link{unhex}}, \code{\link{unhex}},
  \code{\link{unhex,Column-method}}

Other stat functions: \code{\link{approxQuantile}},
  \code{\link{approxQuantile,SparkDataFrame,character,numeric,numeric-method}};
  \code{\link{cov}}, \code{\link{cov}}, \code{\link{cov}},
  \code{\link{cov,SparkDataFrame-method}},
  \code{\link{cov,characterOrColumn-method}},
  \code{\link{covar_samp}}, \code{\link{covar_samp}},
  \code{\link{covar_samp,characterOrColumn,characterOrColumn-method}};
  \code{\link{crosstab}},
  \code{\link{crosstab,SparkDataFrame,character,character-method}};
  \code{\link{freqItems}},
  \code{\link{freqItems,SparkDataFrame,character-method}};
  \code{\link{sampleBy}}, \code{\link{sampleBy}},
  \code{\link{sampleBy,SparkDataFrame,character,list,numeric-method}}
}

