% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/DataFrame.R, R/generics.R
\docType{methods}
\name{merge}
\alias{merge}
\alias{merge,SparkDataFrame,SparkDataFrame-method}
\title{Merges two data frames}
\usage{
\S4method{merge}{SparkDataFrame,SparkDataFrame}(x, y, by = intersect(names(x),
  names(y)), by.x = by, by.y = by, all = FALSE, all.x = all,
  all.y = all, sort = TRUE, suffixes = c("_x", "_y"), ...)

merge(x, y, ...)
}
\arguments{
\item{x}{the first data frame to be joined.}

\item{y}{the second data frame to be joined.}

\item{by}{a character vector specifying the join columns. If by is not
specified, the common column names in \code{x} and \code{y} will be used.
If by or both by.x and by.y are explicitly set to NULL or of length 0, the Cartesian
Product of x and y will be returned.}

\item{by.x}{a character vector specifying the joining columns for x.}

\item{by.y}{a character vector specifying the joining columns for y.}

\item{all}{a boolean value setting \code{all.x} and \code{all.y}
if any of them are unset.}

\item{all.x}{a boolean value indicating whether all the rows in x should
be including in the join.}

\item{all.y}{a boolean value indicating whether all the rows in y should
be including in the join.}

\item{sort}{a logical argument indicating whether the resulting columns should be sorted.}

\item{suffixes}{a string vector of length 2 used to make colnames of
\code{x} and \code{y} unique.
The first element is appended to each colname of \code{x}.
The second element is appended to each colname of \code{y}.}

\item{...}{additional argument(s) passed to the method.}
}
\description{
Merges two data frames
}
\details{
If all.x and all.y are set to FALSE, a natural join will be returned. If
  all.x is set to TRUE and all.y is set to FALSE, a left outer join will
  be returned. If all.x is set to FALSE and all.y is set to TRUE, a right
  outer join will be returned. If all.x and all.y are set to TRUE, a full
  outer join will be returned.
}
\note{
merge since 1.5.0
}
\examples{
\dontrun{
sparkR.session()
df1 <- read.json(path)
df2 <- read.json(path2)
merge(df1, df2) # Performs an inner join by common columns
merge(df1, df2, by = "col1") # Performs an inner join based on expression
merge(df1, df2, by.x = "col1", by.y = "col2", all.y = TRUE)
merge(df1, df2, by.x = "col1", by.y = "col2", all.x = TRUE)
merge(df1, df2, by.x = "col1", by.y = "col2", all.x = TRUE, all.y = TRUE)
merge(df1, df2, by.x = "col1", by.y = "col2", all = TRUE, sort = FALSE)
merge(df1, df2, by = "col1", all = TRUE, suffixes = c("-X", "-Y"))
merge(df1, df2, by = NULL) # Performs a Cartesian join
}
}
\seealso{
\link{join} \link{crossJoin}

Other SparkDataFrame functions: \code{\link{$}},
  \code{\link{$,SparkDataFrame-method}}, \code{\link{$<-}},
  \code{\link{$<-,SparkDataFrame-method}},
  \code{\link{select}}, \code{\link{select}},
  \code{\link{select,SparkDataFrame,Column-method}},
  \code{\link{select,SparkDataFrame,character-method}},
  \code{\link{select,SparkDataFrame,list-method}};
  \code{\link{SparkDataFrame-class}}; \code{\link{[}},
  \code{\link{[,SparkDataFrame-method}}, \code{\link{[[}},
  \code{\link{[[,SparkDataFrame,numericOrcharacter-method}},
  \code{\link{[[<-}},
  \code{\link{[[<-,SparkDataFrame,numericOrcharacter-method}},
  \code{\link{subset}}, \code{\link{subset}},
  \code{\link{subset,SparkDataFrame-method}};
  \code{\link{agg}}, \code{\link{agg}}, \code{\link{agg}},
  \code{\link{agg,GroupedData-method}},
  \code{\link{agg,SparkDataFrame-method}},
  \code{\link{summarize}}, \code{\link{summarize}},
  \code{\link{summarize}},
  \code{\link{summarize,GroupedData-method}},
  \code{\link{summarize,SparkDataFrame-method}};
  \code{\link{arrange}}, \code{\link{arrange}},
  \code{\link{arrange}},
  \code{\link{arrange,SparkDataFrame,Column-method}},
  \code{\link{arrange,SparkDataFrame,character-method}},
  \code{\link{orderBy,SparkDataFrame,characterOrColumn-method}};
  \code{\link{as.data.frame}},
  \code{\link{as.data.frame,SparkDataFrame-method}};
  \code{\link{attach}},
  \code{\link{attach,SparkDataFrame-method}};
  \code{\link{cache}}, \code{\link{cache}},
  \code{\link{cache,SparkDataFrame-method}};
  \code{\link{coalesce}}, \code{\link{coalesce}},
  \code{\link{coalesce}},
  \code{\link{coalesce,Column-method}},
  \code{\link{coalesce,SparkDataFrame-method}};
  \code{\link{collect}}, \code{\link{collect}},
  \code{\link{collect,SparkDataFrame-method}};
  \code{\link{colnames}}, \code{\link{colnames}},
  \code{\link{colnames,SparkDataFrame-method}},
  \code{\link{colnames<-}}, \code{\link{colnames<-}},
  \code{\link{colnames<-,SparkDataFrame-method}},
  \code{\link{columns}}, \code{\link{columns}},
  \code{\link{columns,SparkDataFrame-method}},
  \code{\link{names}},
  \code{\link{names,SparkDataFrame-method}},
  \code{\link{names<-}},
  \code{\link{names<-,SparkDataFrame-method}};
  \code{\link{coltypes}}, \code{\link{coltypes}},
  \code{\link{coltypes,SparkDataFrame-method}},
  \code{\link{coltypes<-}}, \code{\link{coltypes<-}},
  \code{\link{coltypes<-,SparkDataFrame,character-method}};
  \code{\link{count,SparkDataFrame-method}},
  \code{\link{nrow}}, \code{\link{nrow}},
  \code{\link{nrow,SparkDataFrame-method}};
  \code{\link{createOrReplaceTempView}},
  \code{\link{createOrReplaceTempView}},
  \code{\link{createOrReplaceTempView,SparkDataFrame,character-method}};
  \code{\link{crossJoin}},
  \code{\link{crossJoin,SparkDataFrame,SparkDataFrame-method}};
  \code{\link{dapplyCollect}}, \code{\link{dapplyCollect}},
  \code{\link{dapplyCollect,SparkDataFrame,function-method}};
  \code{\link{dapply}}, \code{\link{dapply}},
  \code{\link{dapply,SparkDataFrame,function,structType-method}};
  \code{\link{describe}}, \code{\link{describe}},
  \code{\link{describe}},
  \code{\link{describe,SparkDataFrame,ANY-method}},
  \code{\link{describe,SparkDataFrame,character-method}},
  \code{\link{describe,SparkDataFrame-method}},
  \code{\link{summary}}, \code{\link{summary}},
  \code{\link{summary,SparkDataFrame-method}};
  \code{\link{dim}},
  \code{\link{dim,SparkDataFrame-method}};
  \code{\link{distinct}}, \code{\link{distinct}},
  \code{\link{distinct,SparkDataFrame-method}},
  \code{\link{unique}},
  \code{\link{unique,SparkDataFrame-method}};
  \code{\link{dropDuplicates}},
  \code{\link{dropDuplicates}},
  \code{\link{dropDuplicates,SparkDataFrame-method}};
  \code{\link{dropna}}, \code{\link{dropna}},
  \code{\link{dropna,SparkDataFrame-method}},
  \code{\link{fillna}}, \code{\link{fillna}},
  \code{\link{fillna,SparkDataFrame-method}},
  \code{\link{na.omit}}, \code{\link{na.omit}},
  \code{\link{na.omit,SparkDataFrame-method}};
  \code{\link{drop}}, \code{\link{drop}},
  \code{\link{drop}}, \code{\link{drop,ANY-method}},
  \code{\link{drop,SparkDataFrame-method}};
  \code{\link{dtypes}}, \code{\link{dtypes}},
  \code{\link{dtypes,SparkDataFrame-method}};
  \code{\link{except}}, \code{\link{except}},
  \code{\link{except,SparkDataFrame,SparkDataFrame-method}};
  \code{\link{explain}}, \code{\link{explain}},
  \code{\link{explain,SparkDataFrame-method}};
  \code{\link{filter}}, \code{\link{filter}},
  \code{\link{filter,SparkDataFrame,characterOrColumn-method}},
  \code{\link{where}}, \code{\link{where}},
  \code{\link{where,SparkDataFrame,characterOrColumn-method}};
  \code{\link{first}}, \code{\link{first}},
  \code{\link{first}},
  \code{\link{first,SparkDataFrame-method}},
  \code{\link{first,characterOrColumn-method}};
  \code{\link{gapplyCollect}}, \code{\link{gapplyCollect}},
  \code{\link{gapplyCollect}},
  \code{\link{gapplyCollect,GroupedData-method}},
  \code{\link{gapplyCollect,SparkDataFrame-method}};
  \code{\link{gapply}}, \code{\link{gapply}},
  \code{\link{gapply}},
  \code{\link{gapply,GroupedData-method}},
  \code{\link{gapply,SparkDataFrame-method}};
  \code{\link{getNumPartitions}},
  \code{\link{getNumPartitions,SparkDataFrame-method}};
  \code{\link{groupBy}}, \code{\link{groupBy}},
  \code{\link{groupBy,SparkDataFrame-method}},
  \code{\link{group_by}}, \code{\link{group_by}},
  \code{\link{group_by,SparkDataFrame-method}};
  \code{\link{head}},
  \code{\link{head,SparkDataFrame-method}};
  \code{\link{histogram}},
  \code{\link{histogram,SparkDataFrame,characterOrColumn-method}};
  \code{\link{insertInto}}, \code{\link{insertInto}},
  \code{\link{insertInto,SparkDataFrame,character-method}};
  \code{\link{intersect}}, \code{\link{intersect}},
  \code{\link{intersect,SparkDataFrame,SparkDataFrame-method}};
  \code{\link{isLocal}}, \code{\link{isLocal}},
  \code{\link{isLocal,SparkDataFrame-method}};
  \code{\link{join}},
  \code{\link{join,SparkDataFrame,SparkDataFrame-method}};
  \code{\link{limit}}, \code{\link{limit}},
  \code{\link{limit,SparkDataFrame,numeric-method}};
  \code{\link{mutate}}, \code{\link{mutate}},
  \code{\link{mutate,SparkDataFrame-method}},
  \code{\link{transform}}, \code{\link{transform}},
  \code{\link{transform,SparkDataFrame-method}};
  \code{\link{ncol}},
  \code{\link{ncol,SparkDataFrame-method}};
  \code{\link{persist}}, \code{\link{persist}},
  \code{\link{persist,SparkDataFrame,character-method}};
  \code{\link{printSchema}}, \code{\link{printSchema}},
  \code{\link{printSchema,SparkDataFrame-method}};
  \code{\link{randomSplit}}, \code{\link{randomSplit}},
  \code{\link{randomSplit,SparkDataFrame,numeric-method}};
  \code{\link{rbind}}, \code{\link{rbind}},
  \code{\link{rbind,SparkDataFrame-method}};
  \code{\link{registerTempTable}},
  \code{\link{registerTempTable}},
  \code{\link{registerTempTable,SparkDataFrame,character-method}};
  \code{\link{rename}}, \code{\link{rename}},
  \code{\link{rename,SparkDataFrame-method}},
  \code{\link{withColumnRenamed}},
  \code{\link{withColumnRenamed}},
  \code{\link{withColumnRenamed,SparkDataFrame,character,character-method}};
  \code{\link{repartition}}, \code{\link{repartition}},
  \code{\link{repartition,SparkDataFrame-method}};
  \code{\link{sample}}, \code{\link{sample}},
  \code{\link{sample,SparkDataFrame,logical,numeric-method}},
  \code{\link{sample_frac}}, \code{\link{sample_frac}},
  \code{\link{sample_frac,SparkDataFrame,logical,numeric-method}};
  \code{\link{saveAsParquetFile}},
  \code{\link{saveAsParquetFile}},
  \code{\link{saveAsParquetFile,SparkDataFrame,character-method}},
  \code{\link{write.parquet}}, \code{\link{write.parquet}},
  \code{\link{write.parquet,SparkDataFrame,character-method}};
  \code{\link{saveAsTable}}, \code{\link{saveAsTable}},
  \code{\link{saveAsTable,SparkDataFrame,character-method}};
  \code{\link{saveDF}}, \code{\link{saveDF}},
  \code{\link{saveDF,SparkDataFrame,character-method}},
  \code{\link{write.df}}, \code{\link{write.df}},
  \code{\link{write.df}},
  \code{\link{write.df,SparkDataFrame-method}};
  \code{\link{schema}}, \code{\link{schema}},
  \code{\link{schema,SparkDataFrame-method}};
  \code{\link{selectExpr}}, \code{\link{selectExpr}},
  \code{\link{selectExpr,SparkDataFrame,character-method}};
  \code{\link{showDF}}, \code{\link{showDF}},
  \code{\link{showDF,SparkDataFrame-method}};
  \code{\link{show}}, \code{\link{show}},
  \code{\link{show,Column-method}},
  \code{\link{show,GroupedData-method}},
  \code{\link{show,SparkDataFrame-method}},
  \code{\link{show,WindowSpec-method}};
  \code{\link{storageLevel}},
  \code{\link{storageLevel,SparkDataFrame-method}};
  \code{\link{str}},
  \code{\link{str,SparkDataFrame-method}};
  \code{\link{take}}, \code{\link{take}},
  \code{\link{take,SparkDataFrame,numeric-method}};
  \code{\link{union}}, \code{\link{union}},
  \code{\link{union,SparkDataFrame,SparkDataFrame-method}},
  \code{\link{unionAll}}, \code{\link{unionAll}},
  \code{\link{unionAll,SparkDataFrame,SparkDataFrame-method}};
  \code{\link{unpersist}}, \code{\link{unpersist}},
  \code{\link{unpersist,SparkDataFrame-method}};
  \code{\link{withColumn}}, \code{\link{withColumn}},
  \code{\link{withColumn,SparkDataFrame,character-method}};
  \code{\link{with}},
  \code{\link{with,SparkDataFrame-method}};
  \code{\link{write.jdbc}}, \code{\link{write.jdbc}},
  \code{\link{write.jdbc,SparkDataFrame,character,character-method}};
  \code{\link{write.json}}, \code{\link{write.json}},
  \code{\link{write.json,SparkDataFrame,character-method}};
  \code{\link{write.orc}}, \code{\link{write.orc}},
  \code{\link{write.orc,SparkDataFrame,character-method}};
  \code{\link{write.text}}, \code{\link{write.text}},
  \code{\link{write.text,SparkDataFrame,character-method}}
}

