% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/DataFrame.R, R/generics.R
\docType{methods}
\name{dropna}
\alias{dropna}
\alias{dropna,SparkDataFrame-method}
\alias{fillna}
\alias{fillna,SparkDataFrame-method}
\alias{na.omit}
\alias{na.omit,SparkDataFrame-method}
\title{A set of SparkDataFrame functions working with NA values}
\usage{
\S4method{dropna}{SparkDataFrame}(x, how = c("any", "all"),
  minNonNulls = NULL, cols = NULL)

\S4method{na.omit}{SparkDataFrame}(object, how = c("any", "all"),
  minNonNulls = NULL, cols = NULL)

\S4method{fillna}{SparkDataFrame}(x, value, cols = NULL)

dropna(x, how = c("any", "all"), minNonNulls = NULL, cols = NULL)

na.omit(object, ...)

fillna(x, value, cols = NULL)
}
\arguments{
\item{x}{a SparkDataFrame.}

\item{how}{"any" or "all".
if "any", drop a row if it contains any nulls.
if "all", drop a row only if all its values are null.
if \code{minNonNulls} is specified, how is ignored.}

\item{minNonNulls}{if specified, drop rows that have less than
\code{minNonNulls} non-null values.
This overwrites the how parameter.}

\item{cols}{optional list of column names to consider. In \code{fillna},
columns specified in cols that do not have matching data
type are ignored. For example, if value is a character, and
subset contains a non-character column, then the non-character
column is simply ignored.}

\item{object}{a SparkDataFrame.}

\item{value}{value to replace null values with.
             Should be an integer, numeric, character or named list.
             If the value is a named list, then cols is ignored and
             value must be a mapping from column name (character) to
             replacement value. The replacement value must be an
             integer, numeric or character.}

\item{...}{further arguments to be passed to or from other methods.}
}
\value{
A SparkDataFrame.
}
\description{
dropna, na.omit - Returns a new SparkDataFrame omitting rows with null values.

fillna - Replace null values.
}
\note{
dropna since 1.4.0

na.omit since 1.5.0

fillna since 1.4.0
}
\examples{
\dontrun{
sparkR.session()
path <- "path/to/file.json"
df <- read.json(path)
dropna(df)
}
\dontrun{
sparkR.session()
path <- "path/to/file.json"
df <- read.json(path)
fillna(df, 1)
fillna(df, list("age" = 20, "name" = "unknown"))
}
}
\seealso{
Other SparkDataFrame functions: \code{\link{$}},
  \code{\link{$,SparkDataFrame-method}}, \code{\link{$<-}},
  \code{\link{$<-,SparkDataFrame-method}},
  \code{\link{select}}, \code{\link{select}},
  \code{\link{select,SparkDataFrame,Column-method}},
  \code{\link{select,SparkDataFrame,character-method}},
  \code{\link{select,SparkDataFrame,list-method}};
  \code{\link{SparkDataFrame-class}}; \code{\link{[}},
  \code{\link{[,SparkDataFrame-method}}, \code{\link{[[}},
  \code{\link{[[,SparkDataFrame,numericOrcharacter-method}},
  \code{\link{[[<-}},
  \code{\link{[[<-,SparkDataFrame,numericOrcharacter-method}},
  \code{\link{subset}}, \code{\link{subset}},
  \code{\link{subset,SparkDataFrame-method}};
  \code{\link{agg}}, \code{\link{agg}}, \code{\link{agg}},
  \code{\link{agg,GroupedData-method}},
  \code{\link{agg,SparkDataFrame-method}},
  \code{\link{summarize}}, \code{\link{summarize}},
  \code{\link{summarize}},
  \code{\link{summarize,GroupedData-method}},
  \code{\link{summarize,SparkDataFrame-method}};
  \code{\link{arrange}}, \code{\link{arrange}},
  \code{\link{arrange}},
  \code{\link{arrange,SparkDataFrame,Column-method}},
  \code{\link{arrange,SparkDataFrame,character-method}},
  \code{\link{orderBy,SparkDataFrame,characterOrColumn-method}};
  \code{\link{as.data.frame}},
  \code{\link{as.data.frame,SparkDataFrame-method}};
  \code{\link{attach}},
  \code{\link{attach,SparkDataFrame-method}};
  \code{\link{cache}}, \code{\link{cache}},
  \code{\link{cache,SparkDataFrame-method}};
  \code{\link{coalesce}}, \code{\link{coalesce}},
  \code{\link{coalesce}},
  \code{\link{coalesce,Column-method}},
  \code{\link{coalesce,SparkDataFrame-method}};
  \code{\link{collect}}, \code{\link{collect}},
  \code{\link{collect,SparkDataFrame-method}};
  \code{\link{colnames}}, \code{\link{colnames}},
  \code{\link{colnames,SparkDataFrame-method}},
  \code{\link{colnames<-}}, \code{\link{colnames<-}},
  \code{\link{colnames<-,SparkDataFrame-method}},
  \code{\link{columns}}, \code{\link{columns}},
  \code{\link{columns,SparkDataFrame-method}},
  \code{\link{names}},
  \code{\link{names,SparkDataFrame-method}},
  \code{\link{names<-}},
  \code{\link{names<-,SparkDataFrame-method}};
  \code{\link{coltypes}}, \code{\link{coltypes}},
  \code{\link{coltypes,SparkDataFrame-method}},
  \code{\link{coltypes<-}}, \code{\link{coltypes<-}},
  \code{\link{coltypes<-,SparkDataFrame,character-method}};
  \code{\link{count,SparkDataFrame-method}},
  \code{\link{nrow}}, \code{\link{nrow}},
  \code{\link{nrow,SparkDataFrame-method}};
  \code{\link{createOrReplaceTempView}},
  \code{\link{createOrReplaceTempView}},
  \code{\link{createOrReplaceTempView,SparkDataFrame,character-method}};
  \code{\link{crossJoin}},
  \code{\link{crossJoin,SparkDataFrame,SparkDataFrame-method}};
  \code{\link{dapplyCollect}}, \code{\link{dapplyCollect}},
  \code{\link{dapplyCollect,SparkDataFrame,function-method}};
  \code{\link{dapply}}, \code{\link{dapply}},
  \code{\link{dapply,SparkDataFrame,function,structType-method}};
  \code{\link{describe}}, \code{\link{describe}},
  \code{\link{describe}},
  \code{\link{describe,SparkDataFrame,ANY-method}},
  \code{\link{describe,SparkDataFrame,character-method}},
  \code{\link{describe,SparkDataFrame-method}},
  \code{\link{summary}}, \code{\link{summary}},
  \code{\link{summary,SparkDataFrame-method}};
  \code{\link{dim}},
  \code{\link{dim,SparkDataFrame-method}};
  \code{\link{distinct}}, \code{\link{distinct}},
  \code{\link{distinct,SparkDataFrame-method}},
  \code{\link{unique}},
  \code{\link{unique,SparkDataFrame-method}};
  \code{\link{dropDuplicates}},
  \code{\link{dropDuplicates}},
  \code{\link{dropDuplicates,SparkDataFrame-method}};
  \code{\link{drop}}, \code{\link{drop}},
  \code{\link{drop}}, \code{\link{drop,ANY-method}},
  \code{\link{drop,SparkDataFrame-method}};
  \code{\link{dtypes}}, \code{\link{dtypes}},
  \code{\link{dtypes,SparkDataFrame-method}};
  \code{\link{except}}, \code{\link{except}},
  \code{\link{except,SparkDataFrame,SparkDataFrame-method}};
  \code{\link{explain}}, \code{\link{explain}},
  \code{\link{explain,SparkDataFrame-method}};
  \code{\link{filter}}, \code{\link{filter}},
  \code{\link{filter,SparkDataFrame,characterOrColumn-method}},
  \code{\link{where}}, \code{\link{where}},
  \code{\link{where,SparkDataFrame,characterOrColumn-method}};
  \code{\link{first}}, \code{\link{first}},
  \code{\link{first}},
  \code{\link{first,SparkDataFrame-method}},
  \code{\link{first,characterOrColumn-method}};
  \code{\link{gapplyCollect}}, \code{\link{gapplyCollect}},
  \code{\link{gapplyCollect}},
  \code{\link{gapplyCollect,GroupedData-method}},
  \code{\link{gapplyCollect,SparkDataFrame-method}};
  \code{\link{gapply}}, \code{\link{gapply}},
  \code{\link{gapply}},
  \code{\link{gapply,GroupedData-method}},
  \code{\link{gapply,SparkDataFrame-method}};
  \code{\link{getNumPartitions}},
  \code{\link{getNumPartitions,SparkDataFrame-method}};
  \code{\link{groupBy}}, \code{\link{groupBy}},
  \code{\link{groupBy,SparkDataFrame-method}},
  \code{\link{group_by}}, \code{\link{group_by}},
  \code{\link{group_by,SparkDataFrame-method}};
  \code{\link{head}},
  \code{\link{head,SparkDataFrame-method}};
  \code{\link{histogram}},
  \code{\link{histogram,SparkDataFrame,characterOrColumn-method}};
  \code{\link{insertInto}}, \code{\link{insertInto}},
  \code{\link{insertInto,SparkDataFrame,character-method}};
  \code{\link{intersect}}, \code{\link{intersect}},
  \code{\link{intersect,SparkDataFrame,SparkDataFrame-method}};
  \code{\link{isLocal}}, \code{\link{isLocal}},
  \code{\link{isLocal,SparkDataFrame-method}};
  \code{\link{join}},
  \code{\link{join,SparkDataFrame,SparkDataFrame-method}};
  \code{\link{limit}}, \code{\link{limit}},
  \code{\link{limit,SparkDataFrame,numeric-method}};
  \code{\link{merge}}, \code{\link{merge}},
  \code{\link{merge,SparkDataFrame,SparkDataFrame-method}};
  \code{\link{mutate}}, \code{\link{mutate}},
  \code{\link{mutate,SparkDataFrame-method}},
  \code{\link{transform}}, \code{\link{transform}},
  \code{\link{transform,SparkDataFrame-method}};
  \code{\link{ncol}},
  \code{\link{ncol,SparkDataFrame-method}};
  \code{\link{persist}}, \code{\link{persist}},
  \code{\link{persist,SparkDataFrame,character-method}};
  \code{\link{printSchema}}, \code{\link{printSchema}},
  \code{\link{printSchema,SparkDataFrame-method}};
  \code{\link{randomSplit}}, \code{\link{randomSplit}},
  \code{\link{randomSplit,SparkDataFrame,numeric-method}};
  \code{\link{rbind}}, \code{\link{rbind}},
  \code{\link{rbind,SparkDataFrame-method}};
  \code{\link{registerTempTable}},
  \code{\link{registerTempTable}},
  \code{\link{registerTempTable,SparkDataFrame,character-method}};
  \code{\link{rename}}, \code{\link{rename}},
  \code{\link{rename,SparkDataFrame-method}},
  \code{\link{withColumnRenamed}},
  \code{\link{withColumnRenamed}},
  \code{\link{withColumnRenamed,SparkDataFrame,character,character-method}};
  \code{\link{repartition}}, \code{\link{repartition}},
  \code{\link{repartition,SparkDataFrame-method}};
  \code{\link{sample}}, \code{\link{sample}},
  \code{\link{sample,SparkDataFrame,logical,numeric-method}},
  \code{\link{sample_frac}}, \code{\link{sample_frac}},
  \code{\link{sample_frac,SparkDataFrame,logical,numeric-method}};
  \code{\link{saveAsParquetFile}},
  \code{\link{saveAsParquetFile}},
  \code{\link{saveAsParquetFile,SparkDataFrame,character-method}},
  \code{\link{write.parquet}}, \code{\link{write.parquet}},
  \code{\link{write.parquet,SparkDataFrame,character-method}};
  \code{\link{saveAsTable}}, \code{\link{saveAsTable}},
  \code{\link{saveAsTable,SparkDataFrame,character-method}};
  \code{\link{saveDF}}, \code{\link{saveDF}},
  \code{\link{saveDF,SparkDataFrame,character-method}},
  \code{\link{write.df}}, \code{\link{write.df}},
  \code{\link{write.df}},
  \code{\link{write.df,SparkDataFrame-method}};
  \code{\link{schema}}, \code{\link{schema}},
  \code{\link{schema,SparkDataFrame-method}};
  \code{\link{selectExpr}}, \code{\link{selectExpr}},
  \code{\link{selectExpr,SparkDataFrame,character-method}};
  \code{\link{showDF}}, \code{\link{showDF}},
  \code{\link{showDF,SparkDataFrame-method}};
  \code{\link{show}}, \code{\link{show}},
  \code{\link{show,Column-method}},
  \code{\link{show,GroupedData-method}},
  \code{\link{show,SparkDataFrame-method}},
  \code{\link{show,WindowSpec-method}};
  \code{\link{storageLevel}},
  \code{\link{storageLevel,SparkDataFrame-method}};
  \code{\link{str}},
  \code{\link{str,SparkDataFrame-method}};
  \code{\link{take}}, \code{\link{take}},
  \code{\link{take,SparkDataFrame,numeric-method}};
  \code{\link{union}}, \code{\link{union}},
  \code{\link{union,SparkDataFrame,SparkDataFrame-method}},
  \code{\link{unionAll}}, \code{\link{unionAll}},
  \code{\link{unionAll,SparkDataFrame,SparkDataFrame-method}};
  \code{\link{unpersist}}, \code{\link{unpersist}},
  \code{\link{unpersist,SparkDataFrame-method}};
  \code{\link{withColumn}}, \code{\link{withColumn}},
  \code{\link{withColumn,SparkDataFrame,character-method}};
  \code{\link{with}},
  \code{\link{with,SparkDataFrame-method}};
  \code{\link{write.jdbc}}, \code{\link{write.jdbc}},
  \code{\link{write.jdbc,SparkDataFrame,character,character-method}};
  \code{\link{write.json}}, \code{\link{write.json}},
  \code{\link{write.json,SparkDataFrame,character-method}};
  \code{\link{write.orc}}, \code{\link{write.orc}},
  \code{\link{write.orc,SparkDataFrame,character-method}};
  \code{\link{write.text}}, \code{\link{write.text}},
  \code{\link{write.text,SparkDataFrame,character-method}}
}

